#!/usr/bin/perl
# Read data generated by Spacechart's gen_spacechart program and 
# output in OU's format
#
# Output format is: 
# name,right ascention (radians),declination (radians),magnitude,spectral type
# 
# Input format is:
#  RA        DEC      pmRA     pmDEC  plx      mag  BV SpT b? dV   vper Name : genetive name
# Sample:
#  064509.25 -164247.3 -000546.0-001223.100379.2 -1.4400.01A0 1            Sirius : alp CMa

use Getopt::Std;

$PI = 3.14159265357989;

while (<STDIN>) {
	if ( /^(\d{2})(\d{2})(\d{2}\.\d{2}) (.\d{2})([\d\.]+) [\-+\.\d]+ (.\d\.\d{2}).....(\w\d)..[\s\d\.]+(.*?):(.*)$/ ) {
		$ra_hours = $1;
		$ra_minutes = $2;
		$ra_seconds = $3;
		$dec_degreess = $4;
		$dec_minutes = $5;
		$mag = $6;
		$type = $7;
		$short_name = $8;
		$short_name =~ s/  //g;
		$short_name =~ s/ $//g;
		$long_name = $9;
		$long_name =~ s/^\s+//g;
		$ra = convertdeg_radians(convertra_deg($ra_hours,$ra_minutes,$ra_seconds));
		$dec = convertdeg_radians(convertdec_deg($dec_degrees,$dec_minutes));
		$short_name=$long_name if $short_name eq "" ;
		printf ("%s,%.6f,%.6f,%.2f,%s\n",$short_name,$ra,$dec,$mag,$type); # if $ra != 0 && $dec != 0 && $short_name =~ /\w/;
	}
}

exit 0;


sub convertdeg_radians {
	my ($degrees) = @_;
	return $degrees*$PI/180;
}

sub convertra_deg {
	my ($hour,$min,$sec) = @_ ;
	return 0 if $hour < 0 or $hour > 24 or $min < 0 or $min > 60 or $sec < 0 or $sec > 60;
	return 15*($hour+$min/60+$sec/3600);
}

sub convertdec_deg {
	my ($degrees,$minutes) = @_ ;
	return $degrees+$minutes/60;
}
